@@ -477,6 +477,8 @@ class ApiDef(object):
         assert_error(len(items) in [1, 2, 3, 4], '无效的api定义', lineno, line)
         api, method, auth, proto = items[0], 'GET', None, 'json'
         method = 'GET' if len(items) == 1 or items[1].upper() != 'POST' else 'POST'
+        if items[1].upper() == 'ANY':
+            method = 'Any'
         if len(items) in [3, 4]:
             auth = items[2]
             if auth == 'none':
