@@ -310,7 +310,6 @@ class ApiDefV4(object):
             func %s(c echo.Context) error {
                 r := &%s{}
 
-                plugin.GetBeforeRequestHook()(c)
                 c.Response().Before(func() {
                     plugin.GetAfterRequestHook()(c)
                 })
@@ -325,7 +324,6 @@ class ApiDefV4(object):
             func %s(c echo.Context) error {
                 r := &%s{}
 
-                plugin.GetBeforeRequestHook()(c)
                 c.Response().Before(func() {
                     plugin.GetAfterRequestHook()(c)
                 })
@@ -347,7 +345,6 @@ class ApiDefV4(object):
                     return err
                 }
 
-                plugin.GetBeforeRequestHook()(c)
                 c.Response().Before(func() {
                     plugin.GetAfterRequestHook()(c)
                 })
@@ -368,7 +365,6 @@ class ApiDefV4(object):
                     return err
                 }
 
-                plugin.GetBeforeRequestHook()(c)
                 c.Response().Before(func() {
                     plugin.GetAfterRequestHook()(c)
                 })
@@ -439,6 +435,8 @@ class ApiDefV4(object):
         assert_error(len(items) in [1, 2, 3, 4], '无效的api定义', lineno, line)
         api, method, auth, proto = items[0], 'GET', None, 'json'
         method = 'GET' if len(items) == 1 or items[1].upper() != 'POST' else 'POST'
+        if items[1].upper() == 'ANY':
+            method = 'Any'
         if len(items) in [3, 4]:
             auth = items[2]
             if auth == 'none':
@@ -711,6 +709,7 @@ class ApiModelV4(object):
         VERSION = 'v1'
         lineno = 1
         root = lines[0].strip()
+        print(root, type(root), root[0], type(root[0]))
         assert_error(is_valid_var(root[0]), '开头必须是有效字母', lineno, root)
         items = root.split(' ')
         assert_error(len(items) >= 2, '无效的apimodel', lineno, root)
