@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #coding: utf-8
 #by yangbin at 2018.11.28
-
+from __future__ import print_function
 vlogs = {
     '0.0.8': 'add text search template',
     '0.0.9': 'update service template url; auto check version',
@@ -30,11 +30,15 @@ vlogs = {
     '0.2.10': 'go mod vendor auto',
     '0.2.11': 'update orm AllResultTo',
     '0.2.12': 'add form tag for apimodel',
-    '0.3.0': 'add new struct v4'
+    '0.3.0': 'add new struct v4',
+    '0.3.1': 'auto load .env',
+    '0.3.2': 'fix load .env',
+    '0.3.3': 'add any router',
+    '0.3.4': 'add python3 support'
 }
 
 name = 'm2c'
-version = '0.3.0'
+version = '0.3.4'
 
 from .conf import M2C_PATH, Color
 from .helper import m2c_version
@@ -47,24 +51,28 @@ def change_log():
     if curv == version:
         return
 
-    print Color.red(u'当前项目使用的m2c版本: %s' % curv)
-    print Color.red(u'使用m2c apicode 或者m2c objcode 可以更新当前版本')
-    print Color.red(u'注意以下更新:')
-    for v, msg in vlogs.iteritems():
+    print(Color.red(u'当前项目使用的m2c版本: %s' % curv))
+    print(Color.red(u'使用m2c apicode 或者m2c objcode 可以更新当前版本'))
+    print(Color.red(u'注意以下更新:'))
+    for v, msg in vlogs.items():
         if v > curv:
-            print v, msg
+            print(v, msg)
 
 
 def check_version():
     import os
+    import random
     from .conf import Color
+    if random.randint(0, 10) % 2 == 0:
+        return
+    # random check for speed up
     change_log()
     text = os.popen('pip search %s' % name).read()
     need_update = False
     for line in text.splitlines():
-        print line
+        print(line)
         line = line.strip()
         if line.startswith('LATEST:'):
             need_update = True
     if need_update:
-        print Color.red('run: pip install -U %s, update it!' % name)
+        print(Color.red('run: pip install -U %s, update it!' % name))
